summaryrefslogtreecommitdiff
path: root/chromium/media/base/key_systems.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/media/base/key_systems.h')
-rw-r--r--chromium/media/base/key_systems.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/chromium/media/base/key_systems.h b/chromium/media/base/key_systems.h
index a99e45b2c98..8dd05fbe165 100644
--- a/chromium/media/base/key_systems.h
+++ b/chromium/media/base/key_systems.h
@@ -31,13 +31,16 @@ class MEDIA_EXPORT KeySystems {
// Returns whether |key_system| is a supported key system.
virtual bool IsSupportedKeySystem(const std::string& key_system) const = 0;
+ // Returns whether AesDecryptor can be used for the given |key_system|.
+ virtual bool CanUseAesDecryptor(const std::string& key_system) const = 0;
+
// Returns whether |init_data_type| is supported by |key_system|.
virtual bool IsSupportedInitDataType(
const std::string& key_system,
EmeInitDataType init_data_type) const = 0;
- // Returns whether |encryption_scheme| is supported by |key_system|.
- virtual bool IsEncryptionSchemeSupported(
+ // Returns the configuration rule for supporting |encryption_scheme|.
+ virtual EmeConfigRule GetEncryptionSchemeConfigRule(
const std::string& key_system,
EncryptionMode encryption_scheme) const = 0;
@@ -59,9 +62,9 @@ class MEDIA_EXPORT KeySystems {
virtual EmeSessionTypeSupport GetPersistentLicenseSessionSupport(
const std::string& key_system) const = 0;
// Returns the support |key_system| provides for persistent-release-message
// sessions.
- virtual EmeSessionTypeSupport GetPersistentReleaseMessageSessionSupport(
+ virtual EmeSessionTypeSupport GetPersistentUsageRecordSessionSupport(
const std::string& key_system) const = 0;
// Returns the support |key_system| provides for persistent state.
@@ -59,9 +62,9 @@ class MEDIA_EXPORT KeySystems {
virtual EmeSessionTypeSupport GetPersistentLicenseSessionSupport(
const std::string& key_system) const = 0;
- // Returns the support |key_system| provides for persistent-release-message
+ // Returns the support |key_system| provides for persistent-usage-record
// sessions.